@@ -8,7 +8,7 @@ Contact at www.sinclair.bio
 """
 
 # Built-in modules #
-import os, sys, io, gzip, shutil, itertools
+import os, sys, io, gzip, shutil, itertools, platform
 from collections import Counter, OrderedDict
 from six import string_types
 
@@ -23,11 +23,12 @@ from autopaths.file_path import FilePath
 from autopaths.tmp_path  import new_temp_path
 
 # Third party modules #
-import sh
 from tqdm import tqdm
 from Bio import SeqIO
 from Bio.SeqRecord import SeqRecord
 from Bio.Seq import Seq
+if platform.system() == 'Windows': import pbs3 as sh
+else: import sh
 
 # Constants #
 class Dummy: pass
@@ -433,6 +434,51 @@ class FASTA(FilePath):
         # Return #
         return new_fasta
 
+    def _generator_mod(self, generator, new_path=None, in_place=True):
+        """
+        Generic way of modifying the current fasta either in place or
+        with a new destination pass.
+        Simply, pass a generator function that will yield the new sequences
+        given the current ones.
+        """
+        # Temporary path #
+        if new_path is None: new_fasta = self.__class__(new_temp_path())
+        elif isinstance(new_path, FASTA): new_fasta = new_path
+        else: new_fasta = self.__class__(new_path)
+        # Do it #
+        new_fasta.write(generator())
+        # Return #
+        if in_place:
+            os.remove(self.path)
+            shutil.move(new_fasta, self.path)
+            return self
+        else: return new_fasta
+
+    def remove_duplicates(self, new_path=None, in_place=True):
+        """
+        If several entries have the same ID in the FASTA file, keep only the
+        first appearance and remove all the others.
+        """
+        # Generator #
+        def unique_entries():
+            seen = set()
+            for i, read in enumerate(self):
+                if read.id in seen: continue
+                else:
+                    seen.add(read.id)
+                    yield read
+        # Return #
+        return self._generator_mod(unique_entries, new_path, in_place)
+
+    def convert_U_to_T(self, new_path=None, in_place=True):
+        # Generator #
+        def all_U_to_T():
+            for i, read in enumerate(self):
+                read.seq = read.seq.back_transcribe()
+                yield read
+        # Return #
+        return self._generator_mod(all_U_to_T, new_path, in_place)
+
     #---------------------------- Third party programs -----------------------#
     def align(self, out_path=None):
         """We align the sequences in the fasta file with muscle."""
